@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2000-2008, Parallels, Inc. All rights reserved.
+ *  Copyright (C) 2000-2009, Parallels, Inc. All rights reserved.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -37,7 +37,7 @@ int vps_is_run(vps_handler *h, envid_t veid);
  *			 0 - CT unmounted.
  *			-1 - error
  */
-int vps_is_mounted(char *root)
+int vps_is_mounted(const char *root)
 {
 	return vz_fs_is_mounted(root);
 }
@@ -65,7 +65,7 @@ int fsmount(envid_t veid, fs_param *fs, dq_param *dq)
 	return ret;
 }
 
-static int real_umount(envid_t veid, char *root)
+static int real_umount(envid_t veid, const char *root)
 {
 	int i, ret, n;
 
@@ -97,7 +97,7 @@ static int real_umount(envid_t veid, char *root)
  * @param root		CT root.
  * @return		0 on success.
  */
-int fsumount(envid_t veid, char *root)
+int fsumount(envid_t veid, const char *root)
 {
 	int ret;
 
@@ -136,6 +136,21 @@ int vps_mount(vps_handler *h, envid_t veid, fs_param *fs, dq_param *dq,
 		logger(-1, 0, "Container is already mounted");
 		return 0;
 	}
+	/* Execute pre mount scripts */
+	if (!(skip & SKIP_ACTION_SCRIPT)) {
+		snprintf(buf, sizeof(buf), "%svps.%s", VPS_CONF_DIR,
+			PRE_MOUNT_PREFIX);
+		for (i = 0; i < 2; i++) {
+			if (run_pre_script(veid, buf)) {
+				logger(-1, 0, "Error executing mount script %s",
+					buf);
+				fsumount(veid, fs->root);
+				return VZ_ACTIONSCRIPT_ERROR;
+			}
+			snprintf(buf, sizeof(buf), "%s%d.%s", VPS_CONF_DIR,
+				veid, PRE_MOUNT_PREFIX);
+		}
+	}
 	if ((ret = fsmount(veid, fs, dq)))
 		return ret;
 	/* Execute per-CT & global mount scripts */
@@ -166,7 +181,7 @@ int vps_mount(vps_handler *h, envid_t veid, fs_param *fs, dq_param *dq,
  * @param skip		skip unmount action scrips
  * @return		0 on success.
  */
-int vps_umount(vps_handler *h, envid_t veid, char *root, skipFlags skip)
+int vps_umount(vps_handler *h, envid_t veid, const char *root, skipFlags skip)
 {
 	char buf[PATH_LEN];
 	int ret, i;
@@ -194,6 +209,19 @@ int vps_umount(vps_handler *h, envid_t veid, char *root, skipFlags skip)
 	}
 	if (!(ret = fsumount(veid, root)))
 		logger(0, 0, "Container is unmounted");
+	if (!(skip & SKIP_ACTION_SCRIPT)) {
+		snprintf(buf, sizeof(buf), "%s%d.%s", VPS_CONF_DIR,
+			veid, POST_UMOUNT_PREFIX);
+		for (i = 0; i < 2; i++) {
+			if (run_pre_script(veid, buf)) {
+				logger(-1, 0, "Error executing umount script %s",
+					buf);
+				return VZ_ACTIONSCRIPT_ERROR;
+			}
+			snprintf(buf, sizeof(buf), "%svps.%s", VPS_CONF_DIR,
+				POST_UMOUNT_PREFIX);
+		}
+	}
 
 	return ret;
 }
