@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2000-2007 SWsoft. All rights reserved.
+ *  Copyright (C) 2000-2008, Parallels, Inc. All rights reserved.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -48,11 +48,10 @@ char *list2str_c(char *name, char c, list_head_t *head)
 	}
 	if (c)
 		sp += sprintf(sp, "%c", c);
-	if (list_empty(head)) {
-		if (c)
-			sprintf(sp, "%c", c);
+
+	if (list_empty(head))
 		return buf;
-	}
+
 	list_for_each(p, head, list) {
 		if (p->val == NULL)
 			continue;
